@@ -23,8 +23,13 @@
 # CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-import unittest
 
+import platform
+(major, minor, patch) = platform.python_version_tuple()
+if int(major) == 2 and int(minor) < 7:
+    import unittest2 as unittest
+else:
+    import unittest
 
 class TestCase(unittest.TestCase):
     """
