@@ -31,6 +31,9 @@ Test for basic math operations
 import unittest
 from . import TestCase
 
+def _mul(input=None, mul=None):
+    input * mul
+
 class TestBasicMath(TestCase):
     from bitmath import *
     from numbers import Number
@@ -85,6 +88,22 @@ class TestBasicMath(TestCase):
         zero_kib = self.KiB(0)
         self.assertEqual(subtracted, zero_kib)
 
+    def test_absolute_positive_value(self):
+        """abs(PositiveObject) is positive"""
+        self.assertEqual(self.KiB(1), abs(self.KiB(1)))
+
+    def test_absolute_negative_value(self):
+        """abs(NegativeObject) is positive"""
+        self.assertEqual(self.KiB(1), abs(self.KiB(-1)))
+
+    def test_inversion_to_negative(self):
+        """Negating a positive makes a negative"""
+        self.assertEqual(self.KiB(-1), -self.KiB(1))
+
+    def test_inversion_to_positive(self):
+        """Plus'ing a negative makes a positive"""
+        self.assertEqual(self.KiB(1), +self.KiB(-1))
+
     ##################################################################
     # add
     def bitmath_add_bitmath_is_bitmath(self):
@@ -139,14 +158,12 @@ class TestBasicMath(TestCase):
 
     ##################################################################
     # mul
-    # @unittest.skip
-    # def test_bitmath_mul_bitmath_is_bitmath(self):
-    #     """bitmath * bitmath = bitmath"""
-    #     bm1 = self.KiB(1)
-    #     bm2 = self.KiB(2)
-    #     result = bm1 * bm2
-    #     self.assertEqual(result, )
-    #     self.assertIsInstance(result, self.Byte)
+    def test_bitmath_mul_bitmath_is_bitmath(self):
+        """bitmath * bitmath = unsupported"""
+        bm1 = self.KiB(1)
+        bm2 = self.KiB(2)
+        test_values = {'input': bm1, 'mul': bm2}
+        self.assertRaises(TypeError, _mul, **test_values)
 
     def test_bitmath_mul_number_is_bitmath(self):
         """bitmath * number = bitmath"""
